/**
 * Calculates Pi using the Leibniz formula for a given number of iterations.
 * (Identical logic to the AssemblyScript version)
 * @param iterations Number of terms in the series.
 * @returns Approximate value of Pi.
 */
export function calculatePiLeibnizTs(iterations: number): number {
    let pi_div_4: number = 0.0
    let sign: number = 1.0

    for (let i: number = 0; i < iterations; i++) {
        let term = sign / (2.0 * i + 1.0)
        pi_div_4 += term
        sign = -sign // Flip the sign
    }
    return pi_div_4 * 4.0
}

/**
 * Helper function to check if a number is prime (Trial Division).
 * (Identical logic to the AssemblyScript version)
 * @param num The number to check.
 * @returns True if prime, false otherwise.
 */
function isPrimeTs(num: number): boolean {
    if (num <= 1) return false
    if (num <= 3) return true
    if (num % 2 == 0 || num % 3 == 0) return false

    // Only need to check up to sqrt(num)
    // Optimized loop: check 6k ± 1
    for (let i: number = 5; i * i <= num; i = i + 6) {
        if (num % i == 0 || num % (i + 2) == 0) {
            return false
        }
    }
    return true
}

/**
 * Counts prime numbers up to a given limit using trial division.
 * (Identical logic to the AssemblyScript version)
 * @param limit The upper bound (exclusive) to search for primes.
 * @returns The count of prime numbers found.
 */
export function countPrimesTs(limit: number): number {
    let count: number = 0
    for (let i: number = 2; i < limit; i++) {
        if (isPrimeTs(i)) {
            count++
        }
    }
    return count
}

export function addTs(a: number, b: number): number {
    return a + b
}
